==> we-node-client-grpc-java-0.3.0-sources.jar: com/wavesenterprise/protobuf/service/contract/UtilServiceGrpc.java <==
package com.wavesenterprise.protobuf.service.contract;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.16.0)",
    comments = "Source: contract/contract_util_service.proto")
public final class UtilServiceGrpc {

  private UtilServiceGrpc() {}

  public static final String SERVICE_NAME = "wavesenterprise.UtilService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.contract.NodeTimeResponse> getGetNodeTimeMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "GetNodeTime",
      requestType = com.google.protobuf.Empty.class,
      responseType = com.wavesenterprise.protobuf.service.contract.NodeTimeResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.contract.NodeTimeResponse> getGetNodeTimeMethod() {
    io.grpc.MethodDescriptor<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.contract.NodeTimeResponse> getGetNodeTimeMethod;
    if ((getGetNodeTimeMethod = UtilServiceGrpc.getGetNodeTimeMethod) == null) {
      synchronized (UtilServiceGrpc.class) {
        if ((getGetNodeTimeMethod = UtilServiceGrpc.getGetNodeTimeMethod) == null) {
          UtilServiceGrpc.getGetNodeTimeMethod = getGetNodeTimeMethod = 
              io.grpc.MethodDescriptor.<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.contract.NodeTimeResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(
                  "wavesenterprise.UtilService", "GetNodeTime"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.google.protobuf.Empty.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.contract.NodeTimeResponse.getDefaultInstance()))
                  .setSchemaDescriptor(new UtilServiceMethodDescriptorSupplier("GetNodeTime"))
                  .build();
          }
        }
     }
     return getGetNodeTimeMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static UtilServiceStub newStub(io.grpc.Channel channel) {
    return new UtilServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static UtilServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new UtilServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static UtilServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new UtilServiceFutureStub(channel);
  }

  /**
   */
  public static abstract class UtilServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void getNodeTime(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.NodeTimeResponse> responseObserver) {
      asyncUnimplementedUnaryCall(getGetNodeTimeMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getGetNodeTimeMethod(),
            asyncUnaryCall(
              new MethodHandlers<
                com.google.protobuf.Empty,
                com.wavesenterprise.protobuf.service.contract.NodeTimeResponse>(
                  this, METHODID_GET_NODE_TIME)))
          .build();
    }
  }

  /**
   */
  public static final class UtilServiceStub extends io.grpc.stub.AbstractStub<UtilServiceStub> {
    private UtilServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private UtilServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UtilServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new UtilServiceStub(channel, callOptions);
    }

    /**
     */
    public void getNodeTime(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.NodeTimeResponse> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getGetNodeTimeMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class UtilServiceBlockingStub extends io.grpc.stub.AbstractStub<UtilServiceBlockingStub> {
    private UtilServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private UtilServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UtilServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new UtilServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public com.wavesenterprise.protobuf.service.contract.NodeTimeResponse getNodeTime(com.google.protobuf.Empty request) {
      return blockingUnaryCall(
          getChannel(), getGetNodeTimeMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class UtilServiceFutureStub extends io.grpc.stub.AbstractStub<UtilServiceFutureStub> {
    private UtilServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private UtilServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UtilServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new UtilServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.wavesenterprise.protobuf.service.contract.NodeTimeResponse> getNodeTime(
        com.google.protobuf.Empty request) {
      return futureUnaryCall(
          getChannel().newCall(getGetNodeTimeMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_GET_NODE_TIME = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final UtilServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(UtilServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_GET_NODE_TIME:
          serviceImpl.getNodeTime((com.google.protobuf.Empty) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.NodeTimeResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class UtilServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    UtilServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.wavesenterprise.protobuf.service.contract.ContractUtilService.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("UtilService");
    }
  }

  private static final class UtilServiceFileDescriptorSupplier
      extends UtilServiceBaseDescriptorSupplier {
    UtilServiceFileDescriptorSupplier() {}
  }

  private static final class UtilServiceMethodDescriptorSupplier
      extends UtilServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    UtilServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (UtilServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new UtilServiceFileDescriptorSupplier())
              .addMethod(getGetNodeTimeMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> we-node-client-grpc-java-2.0.0-sources.jar: com/wavesenterprise/protobuf/service/contract/UtilServiceGrpc.java <==
package com.wavesenterprise.protobuf.service.contract;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.64.0)",
    comments = "Source: contract/contract_util_service.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class UtilServiceGrpc {

  private UtilServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "wavesenterprise.UtilService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.contract.NodeTimeResponse> getGetNodeTimeMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "GetNodeTime",
      requestType = com.google.protobuf.Empty.class,
      responseType = com.wavesenterprise.protobuf.service.contract.NodeTimeResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.contract.NodeTimeResponse> getGetNodeTimeMethod() {
    io.grpc.MethodDescriptor<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.contract.NodeTimeResponse> getGetNodeTimeMethod;
    if ((getGetNodeTimeMethod = UtilServiceGrpc.getGetNodeTimeMethod) == null) {
      synchronized (UtilServiceGrpc.class) {
        if ((getGetNodeTimeMethod = UtilServiceGrpc.getGetNodeTimeMethod) == null) {
          UtilServiceGrpc.getGetNodeTimeMethod = getGetNodeTimeMethod =
              io.grpc.MethodDescriptor.<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.contract.NodeTimeResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "GetNodeTime"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.google.protobuf.Empty.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.contract.NodeTimeResponse.getDefaultInstance()))
              .setSchemaDescriptor(new UtilServiceMethodDescriptorSupplier("GetNodeTime"))
              .build();
        }
      }
    }
    return getGetNodeTimeMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static UtilServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<UtilServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<UtilServiceStub>() {
        @java.lang.Override
        public UtilServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new UtilServiceStub(channel, callOptions);
        }
      };
    return UtilServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static UtilServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<UtilServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<UtilServiceBlockingStub>() {
        @java.lang.Override
        public UtilServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new UtilServiceBlockingStub(channel, callOptions);
        }
      };
    return UtilServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static UtilServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<UtilServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<UtilServiceFutureStub>() {
        @java.lang.Override
        public UtilServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new UtilServiceFutureStub(channel, callOptions);
        }
      };
    return UtilServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void getNodeTime(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.NodeTimeResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getGetNodeTimeMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service UtilService.
   */
  public static abstract class UtilServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return UtilServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service UtilService.
   */
  public static final class UtilServiceStub
      extends io.grpc.stub.AbstractAsyncStub<UtilServiceStub> {
    private UtilServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UtilServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new UtilServiceStub(channel, callOptions);
    }

    /**
     */
    public void getNodeTime(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.NodeTimeResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getGetNodeTimeMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service UtilService.
   */
  public static final class UtilServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<UtilServiceBlockingStub> {
    private UtilServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UtilServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new UtilServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public com.wavesenterprise.protobuf.service.contract.NodeTimeResponse getNodeTime(com.google.protobuf.Empty request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getGetNodeTimeMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service UtilService.
   */
  public static final class UtilServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<UtilServiceFutureStub> {
    private UtilServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UtilServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new UtilServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.wavesenterprise.protobuf.service.contract.NodeTimeResponse> getNodeTime(
        com.google.protobuf.Empty request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getGetNodeTimeMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_GET_NODE_TIME = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_GET_NODE_TIME:
          serviceImpl.getNodeTime((com.google.protobuf.Empty) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.NodeTimeResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getGetNodeTimeMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              com.google.protobuf.Empty,
              com.wavesenterprise.protobuf.service.contract.NodeTimeResponse>(
                service, METHODID_GET_NODE_TIME)))
        .build();
  }

  private static abstract class UtilServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    UtilServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.wavesenterprise.protobuf.service.contract.ContractUtilService.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("UtilService");
    }
  }

  private static final class UtilServiceFileDescriptorSupplier
      extends UtilServiceBaseDescriptorSupplier {
    UtilServiceFileDescriptorSupplier() {}
  }

  private static final class UtilServiceMethodDescriptorSupplier
      extends UtilServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    UtilServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (UtilServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new UtilServiceFileDescriptorSupplier())
              .addMethod(getGetNodeTimeMethod())
              .build();
        }
      }
    }
    return result;
  }
}
